#ifndef COMMONSTATIC_H
#define COMMONSTATIC_H
#include <QWidget>
#include <QString>

class CommonStatic
{
public:
    static void ErrorMessage(QWidget* parent, QString message);
    static void InfoMessage(QWidget* parent, QString message);

    static bool IsPortrait();
    static QString GetHomeFolder();
    static QString FormatKBytes(int kbytes);

    static bool IsMouseOver(QWidget* w);
};

#endif // COMMONSTATIC_H
